@@ -1,11 +1,13 @@
 /* GENIUS Calculator
- * Copyright (C) 1997-2003 George Lebl
+ * Copyright (C) 1997-2008 Jiri (George) Lebl
  *
- * Author: George Lebl
+ * Author: Jiri (George) Lebl
  *
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of Genius.
+ *
+ * Genius is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -14,9 +16,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the  Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
- * USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -165,7 +165,7 @@ mympz_miller_rabin_test_sure (mpz_srcptr n)
 	  if (evalnode_hook != NULL) {
 		  (*evalnode_hook)();
 	  }
-	  if (interrupted) {
+	  if G_UNLIKELY (interrupted) {
 		  is_prime = 0;
 		  break;
 	  }
@@ -222,11 +222,13 @@ mympz_is_prime (mpz_srcptr n, int miller_rabin_reps)
 	if ( ! mympz_strong_pseudoprime_test_2_3_5_7 (n))
 		return 0;
 
-	if ( ! inited_test) {
+	if G_UNLIKELY ( ! inited_test) {
 		/* set test to 25*10^9 */
 		mpz_init_set_ui (test, 10);
 		mpz_pow_ui (test, test, 9);
 		mpz_mul_ui (test, test, 25);
+
+		inited_test = TRUE;
 	}
 
 	/* if n < 25*10^9, we are now sure this
@@ -241,7 +243,7 @@ mympz_is_prime (mpz_srcptr n, int miller_rabin_reps)
 
 	if (evalnode_hook != NULL)
 		(*evalnode_hook)();
-	if (interrupted)
+	if G_UNLIKELY (interrupted)
 		return 0;
 
 	return mpz_millerrabin (n, miller_rabin_reps-1);
@@ -379,13 +381,13 @@ factor_using_pollard_rho (GArray *fact, mpz_t n, int a_int)
     {
 S2:
       if (evalnode_hook != NULL) {
-	    static int i = 0;
-	    if (i++ > run_hook_every) {
-		    i = 0;
-		    (*evalnode_hook) ();
-	    }
+	      static int i = 0;
+	      if G_UNLIKELY ((i++ & RUN_HOOK_EVERY_MASK) == RUN_HOOK_EVERY_MASK) {
+		      (*evalnode_hook)();
+		      i = 0;
+	      }
       }
-      if (interrupted) {
+      if G_UNLIKELY (interrupted) {
 	      mpz_set_ui (n, 1);
 	      continue;
       }
@@ -521,7 +523,7 @@ mympz_pollard_rho_factorize (mpz_srcptr t)
 
 	mpz_clear (n);
 
-	if (interrupted) {
+	if G_UNLIKELY (interrupted) {
 		mympz_factorization_free (fact);
 		return NULL;
 	}
